# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import winrt.system
from winrt import _winrt_microsoft_ui_xaml_controls_animatedvisuals

__all__ = [
    "AnimatedAcceptVisualSource",
    "AnimatedBackVisualSource",
    "AnimatedChevronDownSmallVisualSource",
    "AnimatedChevronRightDownSmallVisualSource",
    "AnimatedChevronUpDownSmallVisualSource",
    "AnimatedFindVisualSource",
    "AnimatedGlobalNavigationButtonVisualSource",
    "AnimatedSettingsVisualSource",
]

AnimatedAcceptVisualSource = _winrt_microsoft_ui_xaml_controls_animatedvisuals.AnimatedAcceptVisualSource
AnimatedBackVisualSource = _winrt_microsoft_ui_xaml_controls_animatedvisuals.AnimatedBackVisualSource
AnimatedChevronDownSmallVisualSource = _winrt_microsoft_ui_xaml_controls_animatedvisuals.AnimatedChevronDownSmallVisualSource
AnimatedChevronRightDownSmallVisualSource = _winrt_microsoft_ui_xaml_controls_animatedvisuals.AnimatedChevronRightDownSmallVisualSource
AnimatedChevronUpDownSmallVisualSource = _winrt_microsoft_ui_xaml_controls_animatedvisuals.AnimatedChevronUpDownSmallVisualSource
AnimatedFindVisualSource = _winrt_microsoft_ui_xaml_controls_animatedvisuals.AnimatedFindVisualSource
AnimatedGlobalNavigationButtonVisualSource = _winrt_microsoft_ui_xaml_controls_animatedvisuals.AnimatedGlobalNavigationButtonVisualSource
AnimatedSettingsVisualSource = _winrt_microsoft_ui_xaml_controls_animatedvisuals.AnimatedSettingsVisualSource
